@@ -32,10 +32,6 @@ Searchdoc.Navigation = new function() {
             case 74: // j
             case 75: // k
             case 76: // l
-            case 67: // c - dvorak
-            case 72: // h
-            case 84: // t
-            case 78: // n
                 this.clearMoveTimeout();
                 break;
         }
@@ -43,15 +39,14 @@ Searchdoc.Navigation = new function() {
 
     this.onkeydown = function(e) {
         if (!this.navigationActive) return;
+
         switch (e.keyCode) {
             case 37: //Event.KEY_LEFT:
             case 74: // j (qwerty)
-            case 72: // h (dvorak)
                 if (this.moveLeft()) e.preventDefault();
                 break;
             case 38: //Event.KEY_UP:
             case 73: // i (qwerty)
-            case 67: // c (dvorak)
                 if (e.keyCode == 38 || e.ctrlKey) {
                     if (this.moveUp()) e.preventDefault();
                     this.startMoveTimeout(false);
@@ -59,28 +54,31 @@ Searchdoc.Navigation = new function() {
                 break;
             case 39: //Event.KEY_RIGHT:
             case 76: // l (qwerty)
-            case 78: // n (dvorak)
                 if (this.moveRight()) e.preventDefault();
                 break;
             case 40: //Event.KEY_DOWN:
             case 75: // k (qwerty)
-            case 84: // t (dvorak)
                 if (e.keyCode == 40 || e.ctrlKey) {
                     if (this.moveDown()) e.preventDefault();
                     this.startMoveTimeout(true);
                 }
                 break;
-            case 9: //Event.KEY_TAB:
             case 13: //Event.KEY_RETURN:
+                if(e.target.dataset["turbolinks"]) { break; }
                 if (this.$current) this.select(this.$current);
                 break;
-            case 83: // s (qwerty)
-            case 79: // o (dvorak)
+            case 83: // s (qwerty) - Focuses search
                 if (e.ctrlKey) {
                     $('#search').focus();
                     e.preventDefault();
                 }
                 break;
+            case 191: // / - Search by pressing "/"
+                if( !$('#search').is(":focus") ) {
+                    $('#search').focus();
+                    e.preventDefault();
+                }
+                break;
         }
         if (e.ctrlKey && e.shiftKey) this.select(this.$current);
     };
@@ -91,7 +89,6 @@ Searchdoc.Navigation = new function() {
     };
 
     this.startMoveTimeout = function(isDown) {
-        if (!$.browser.mozilla && !$.browser.opera) return;
         if (this.moveTimeout) this.clearMoveTimeout();
         var _this = this;
 
@@ -137,11 +134,10 @@ function scrollIntoView(element, view) {
 
 // panel.js -----------------------------------------------
 
-Searchdoc.Panel = function(element, data, tree, frame) {
+Searchdoc.Panel = function(element, data, tree) {
     this.$element = $(element);
     this.$input = $('input', element).eq(0);
     this.$result = $('.result ul', element).eq(0);
-    this.frame = frame;
     this.$current = null;
     this.$view = this.$result.parent();
     this.data = data;
@@ -195,6 +191,26 @@ Searchdoc.Panel.prototype = $.extend({}, Searchdoc.Navigation, new function() {
         }
     };
 
+    this.toggle = function(keys) {
+        var keysIndex = 0;
+        var _tree = this.tree;
+        var _this = this;
+        $.each(_tree.$list[0].children, function(i, li) {
+            if(keys.length > keysIndex) {
+                $li = $(li);
+                if($li.text().split(" ")[0] == keys[keysIndex]) {
+                    if($li.find('.icon').length > 0) {
+                        _tree.toggle($li);
+                    }
+                    keysIndex += 1;
+                    if(keysIndex == keys.length) {
+                        _tree.highlight($li)
+                    }
+                }
+            }
+        });
+    };
+
     this.addResults = function(results, isLast) {
         var target = this.$result.get(0);
         if (this.firstRun && (results.length > 0 || isLast)) {
@@ -211,16 +227,20 @@ Searchdoc.Panel.prototype = $.extend({}, Searchdoc.Navigation, new function() {
             if (this.selectFirstMatch) this.select();
             scrollIntoView(this.$current[0], this.$view[0]);
         }
-        if (jQuery.browser.msie) this.$element[0].className += '';
     };
 
     this.open = function(src) {
-        this.frame.location.href = '../' + src;
-        if (this.frame.highlight) this.frame.highlight(src);
+        var location = $('meta[name="data-rel-prefix"]').attr("content") + src;
+        if (window.location.protocol === "file:") {
+            window.location.href = location;
+        } else {
+            Turbolinks.visit(location);
+        }
+        if (this.highlight) this.highlight(src);
     };
 
     this.select = function() {
-        this.open(this.$current.data('path'));
+        this.open(this.$current.attr('data-path'));
     };
 
     this.move = function(isDown) {
@@ -249,7 +269,7 @@ Searchdoc.Panel.prototype = $.extend({}, Searchdoc.Navigation, new function() {
         html += hlt(result.namespace) + '</p>';
         if (result.snippet) html += '<p class="snippet">' + stripHTML(result.snippet) + '</p>';
         li.innerHTML = html;
-        jQuery.data(li, 'path', result.path);
+        $(li).attr('data-path', result.path)
         return li;
     }
 
@@ -314,7 +334,6 @@ Searchdoc.Tree.prototype = $.extend({}, Searchdoc.Navigation, new function() {
         });
 
         this.initNavigation();
-        if (jQuery.browser.msie) document.body.className += '';
     };
 
     this.select = function($li) {
