@@ -3,11 +3,7 @@ require 'pathname'
 require 'fileutils'
 require 'json'
 
-require 'sdoc/templatable'
-
 class SDoc::Merge
-  include SDoc::Templatable
-
   FLAG_FILE = "created.rid"
 
   def initialize()
@@ -20,9 +16,6 @@ class SDoc::Merge
 
   def merge(options)
     parse_options options
-
-    @outputdir = Pathname.new( @op_dir )
-
     check_directories
     setup_output_dir
     setup_names
@@ -30,7 +23,7 @@ class SDoc::Merge
     copy_docs if @urls.empty?
     merge_search_index
     merge_tree
-    generate_index_file
+    copy_index_file
   end
 
   def parse_options(options)
@@ -56,7 +49,6 @@ class SDoc::Merge
       end
     end
     opts.parse! options
-    @template_dir = Pathname.new(RDoc::Options.new.template_dir_for 'merge')
     @directories = options.dup
   end
 
@@ -70,7 +62,7 @@ class SDoc::Merge
       subtree = JSON.parse(data, :max_nesting => 0)
       item = [
         name,
-        url + '/' + extract_index_path(dir),
+        url + '/index.html',
         '',
         append_path(subtree, url)
       ]
@@ -137,24 +129,8 @@ class SDoc::Merge
     end
   end
 
-  def extract_index_path dir
-    filename = File.join dir, 'index.html'
-    content = File.open(filename) { |f| f.read }
-    match = content.match(/<frame\s+src="([^"]+)"\s+name="docwin"/mi)
-    if match
-      match[1]
-    else
-      ''
-    end
-  end
-
-  def generate_index_file
-    templatefile = @template_dir + 'index.rhtml'
-    outfile      = @outputdir + 'index.html'
-    url          = @urls.empty? ? @names[0] : @urls[0]
-    index_path   = url + '/' + extract_index_path(@directories[0])
-
-    render_template templatefile, binding(), outfile
+  def copy_index_file
+    FileUtils.cp File.join(@directories[0], 'index.html'), @op_dir
   end
 
   def setup_names
@@ -178,6 +154,7 @@ class SDoc::Merge
           FileUtils.cp_r File.join(dir, item), File.join(@op_dir, name, item), :preserve => true
         end
       end
+      FileUtils.cp File.join(dir, 'index.html'), File.join(@op_dir, name)
     end
   end
 
@@ -191,7 +168,7 @@ class SDoc::Merge
   end
 
   def setup_output_dir
-    if File.exists? @op_dir
+    if File.exist? @op_dir
       error "#{@op_dir} already exists"
     end
     FileUtils.mkdir_p @op_dir
@@ -199,9 +176,9 @@ class SDoc::Merge
 
   def check_directories
     @directories.each do |dir|
-      unless File.exists?(File.join(dir, FLAG_FILE)) &&
-      File.exists?(File.join(dir, RDoc::Generator::SDoc::TREE_FILE)) &&
-      File.exists?(File.join(dir, RDoc::Generator::SDoc::SEARCH_INDEX_FILE))
+      unless File.exist?(File.join(dir, FLAG_FILE)) &&
+      File.exist?(File.join(dir, RDoc::Generator::SDoc::TREE_FILE)) &&
+      File.exist?(File.join(dir, RDoc::Generator::SDoc::SEARCH_INDEX_FILE))
         error "#{dir} does not seem to be an sdoc directory"
       end
     end
